abacusai.model_version_feature_group_schema — AbacusAI documentation

# abacusai.model_version_feature_group_schema

## Classes

`ModelVersionFeatureGroupSchema` | Schema for a feature group used in model version

## Module Contents

class abacusai.model_version_feature_group_schema.ModelVersionFeatureGroupSchema(client, featureGroupId=None, featureGroupName=None, schema={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Schema for a feature group used in model version

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupId (str) – The ID of the feature group.

    - featureGroupName (str) – The name of the feature group.

    - schema (Schema) – List of feature schemas of a feature group.

  feature_group_id
  feature_group_name
  schema
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict